"""
辅助函数
"""

from pathlib import Path
import matplotlib.pyplot as plt
import scipy.io as sio


def save_matrix(matrix, file_name):
    sio.savemat(file_name + '.mat', {'matrix': matrix})


def save_fig(matrix, file_name):
    plt.imshow(matrix)
    plt.savefig(file_name + '.jpg')


def make_dir(outdir):
    Path(outdir).mkdir(parents=True, exist_ok=True)



from simplelayout.cli import get_options
from simplelayout.generator.core import generate_matrix
from simplelayout.generator.utils import save_matrix, save_fig, make_dir


def main():
    options = get_options()
    layout = generate_matrix(options.board_grid, options.unit_grid,
                             options.unit_n, options.positions)
    make_dir(options.outdir)
    save_matrix(layout, options.outdir + '/' + options.file_name)
    save_fig(layout, options.outdir + '/' + options.file_name)


if __name__ == "__main__":
    main()



"""
数据生成的主要逻辑
"""

import numpy as np


def generate_matrix(board_grid: int, unit_grid: int, unit_n: int,
                    positions: list) -> np.ndarray:
    """生成指定布局矩阵

    Args:
        board_grid (int): 布局板分辨率，代表矩形区域的边长像素数
        unit_grid (int): 矩形组件分辨率
        unit_n (int): 组件数
        positions (list): 每个元素代表每个组件的位置
    Returns:
        np.ndarray: 布局矩阵
    """
    # layout = np.zeros((board_grid, board_grid))
    interval = int(board_grid / unit_grid)
    sequences = np.zeros(interval**2)
    sequences[np.array(positions) - 1] = 1
    layout = np.kron(sequences.reshape(interval, interval),
                     np.ones((unit_grid, unit_grid)))
    # for pos in positions:
    #     raw = int(math.floor((pos - 1) / interval))
    #     col = int((pos - 1) % interval)
    #     layout[
    #         (raw * unit_grid):(raw * unit_grid + unit_grid),
    #         (col * unit_grid):(col * unit_grid + unit_grid)
    #     ] = np.ones((unit_grid, unit_grid))
    return layout



import setuptools


with open("README.md", "r", encoding='utf-8') as fr:
    long_descriptions = fr.read()


setuptools.setup(
    name="simplelayout-zhaoxiaoyu1995",
    version="0.1",
    author="zhaoxiaoyu",
    author_email="zhaoxiaoyu1995@foxmail.com",
    description="The Simple Layout Generator",
    long_description=long_descriptions,
    long_description_content_type="text/markdown",
    # url="",
    # project_urls={
    #     "Bug Tracker": "https://github.com/pypa/sampleproject/issues",
    # },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.6",
    install_requires=[
        'numpy',
        'matplotlib',
        'scipy'
    ],
    entry_points={
        'console_scripts': [
            'simplelayout = src.simplelayout.__main__:main'
        ]
    }
)
